==> openhab-5.0.2.tgz: java/org/openhab/core/thing/internal/dto/XmlItemTypeName.java <==

package org.openhab.core.thing.internal.dto;

import javax.annotation.Generated;
import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for itemTypeName.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <pre>
 * &lt;simpleType name="itemTypeName"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *     &lt;enumeration value="Call"/&gt;
 *     &lt;enumeration value="Color"/&gt;
 *     &lt;enumeration value="Contact"/&gt;
 *     &lt;enumeration value="DateTime"/&gt;
 *     &lt;enumeration value="Dimmer"/&gt;
 *     &lt;enumeration value="Group"/&gt;
 *     &lt;enumeration value="Image"/&gt;
 *     &lt;enumeration value="Location"/&gt;
 *     &lt;enumeration value="Number"/&gt;
 *     &lt;enumeration value="Number:Acceleration"/&gt;
 *     &lt;enumeration value="Number:AmountOfSubstance"/&gt;
 *     &lt;enumeration value="Number:Angle"/&gt;
 *     &lt;enumeration value="Number:Area"/&gt;
 *     &lt;enumeration value="Number:ArealDensity"/&gt;
 *     &lt;enumeration value="Number:CatalyticActivity"/&gt;
 *     &lt;enumeration value="Number:Currency"/&gt;
 *     &lt;enumeration value="Number:DataAmount"/&gt;
 *     &lt;enumeration value="Number:DataTransferRate"/&gt;
 *     &lt;enumeration value="Number:Density"/&gt;
 *     &lt;enumeration value="Number:Dimensionless"/&gt;
 *     &lt;enumeration value="Number:ElectricCapacitance"/&gt;
 *     &lt;enumeration value="Number:ElectricCharge"/&gt;
 *     &lt;enumeration value="Number:ElectricConductance"/&gt;
 *     &lt;enumeration value="Number:ElectricConductivity"/&gt;
 *     &lt;enumeration value="Number:ElectricCurrent"/&gt;
 *     &lt;enumeration value="Number:ElectricInductance"/&gt;
 *     &lt;enumeration value="Number:ElectricPotential"/&gt;
 *     &lt;enumeration value="Number:ElectricResistance"/&gt;
 *     &lt;enumeration value="Number:EmissionIntensity"/&gt;
 *     &lt;enumeration value="Number:Energy"/&gt;
 *     &lt;enumeration value="Number:EnergyPrice"/&gt;
 *     &lt;enumeration value="Number:Force"/&gt;
 *     &lt;enumeration value="Number:Frequency"/&gt;
 *     &lt;enumeration value="Number:Illuminance"/&gt;
 *     &lt;enumeration value="Number:Intensity"/&gt;
 *     &lt;enumeration value="Number:Length"/&gt;
 *     &lt;enumeration value="Number:LuminousFlux"/&gt;
 *     &lt;enumeration value="Number:LuminousIntensity"/&gt;
 *     &lt;enumeration value="Number:MagneticFlux"/&gt;
 *     &lt;enumeration value="Number:MagneticFluxDensity"/&gt;
 *     &lt;enumeration value="Number:Mass"/&gt;
 *     &lt;enumeration value="Number:Power"/&gt;
 *     &lt;enumeration value="Number:Pressure"/&gt;
 *     &lt;enumeration value="Number:RadiationDoseAbsorbed"/&gt;
 *     &lt;enumeration value="Number:RadiationDoseEffective"/&gt;
 *     &lt;enumeration value="Number:RadiationSpecificActivity"/&gt;
 *     &lt;enumeration value="Number:RadioactiveActivity"/&gt;
 *     &lt;enumeration value="Number:SolidAngle"/&gt;
 *     &lt;enumeration value="Number:Speed"/&gt;
 *     &lt;enumeration value="Number:Temperature"/&gt;
 *     &lt;enumeration value="Number:Time"/&gt;
 *     &lt;enumeration value="Number:Volume"/&gt;
 *     &lt;enumeration value="Number:VolumetricFlowRate"/&gt;
 *     &lt;enumeration value="Player"/&gt;
 *     &lt;enumeration value="Rollershutter"/&gt;
 *     &lt;enumeration value="String"/&gt;
 *     &lt;enumeration value="Switch"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "itemTypeName")
@XmlEnum
@Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-10-16T21:10:39Z")
public enum XmlItemTypeName {

    @XmlEnumValue("Call")
    CALL("Call"),
    @XmlEnumValue("Color")
    COLOR("Color"),
    @XmlEnumValue("Contact")
    CONTACT("Contact"),
    @XmlEnumValue("DateTime")
    DATE_TIME("DateTime"),
    @XmlEnumValue("Dimmer")
    DIMMER("Dimmer"),
    @XmlEnumValue("Group")
    GROUP("Group"),
    @XmlEnumValue("Image")
    IMAGE("Image"),
    @XmlEnumValue("Location")
    LOCATION("Location"),
    @XmlEnumValue("Number")
    NUMBER("Number"),
    @XmlEnumValue("Number:Acceleration")
    NUMBER_ACCELERATION("Number:Acceleration"),
    @XmlEnumValue("Number:AmountOfSubstance")
    NUMBER_AMOUNT_OF_SUBSTANCE("Number:AmountOfSubstance"),
    @XmlEnumValue("Number:Angle")
    NUMBER_ANGLE("Number:Angle"),
    @XmlEnumValue("Number:Area")
    NUMBER_AREA("Number:Area"),
    @XmlEnumValue("Number:ArealDensity")
    NUMBER_AREAL_DENSITY("Number:ArealDensity"),
    @XmlEnumValue("Number:CatalyticActivity")
    NUMBER_CATALYTIC_ACTIVITY("Number:CatalyticActivity"),
    @XmlEnumValue("Number:Currency")
    NUMBER_CURRENCY("Number:Currency"),
    @XmlEnumValue("Number:DataAmount")
    NUMBER_DATA_AMOUNT("Number:DataAmount"),
    @XmlEnumValue("Number:DataTransferRate")
    NUMBER_DATA_TRANSFER_RATE("Number:DataTransferRate"),
    @XmlEnumValue("Number:Density")
    NUMBER_DENSITY("Number:Density"),
    @XmlEnumValue("Number:Dimensionless")
    NUMBER_DIMENSIONLESS("Number:Dimensionless"),
    @XmlEnumValue("Number:ElectricCapacitance")
    NUMBER_ELECTRIC_CAPACITANCE("Number:ElectricCapacitance"),
    @XmlEnumValue("Number:ElectricCharge")
    NUMBER_ELECTRIC_CHARGE("Number:ElectricCharge"),
    @XmlEnumValue("Number:ElectricConductance")
    NUMBER_ELECTRIC_CONDUCTANCE("Number:ElectricConductance"),
    @XmlEnumValue("Number:ElectricConductivity")
    NUMBER_ELECTRIC_CONDUCTIVITY("Number:ElectricConductivity"),
    @XmlEnumValue("Number:ElectricCurrent")
    NUMBER_ELECTRIC_CURRENT("Number:ElectricCurrent"),
    @XmlEnumValue("Number:ElectricInductance")
    NUMBER_ELECTRIC_INDUCTANCE("Number:ElectricInductance"),
    @XmlEnumValue("Number:ElectricPotential")
    NUMBER_ELECTRIC_POTENTIAL("Number:ElectricPotential"),
    @XmlEnumValue("Number:ElectricResistance")
    NUMBER_ELECTRIC_RESISTANCE("Number:ElectricResistance"),
    @XmlEnumValue("Number:EmissionIntensity")
    NUMBER_EMISSION_INTENSITY("Number:EmissionIntensity"),
    @XmlEnumValue("Number:Energy")
    NUMBER_ENERGY("Number:Energy"),
    @XmlEnumValue("Number:EnergyPrice")
    NUMBER_ENERGY_PRICE("Number:EnergyPrice"),
    @XmlEnumValue("Number:Force")
    NUMBER_FORCE("Number:Force"),
    @XmlEnumValue("Number:Frequency")
    NUMBER_FREQUENCY("Number:Frequency"),
    @XmlEnumValue("Number:Illuminance")
    NUMBER_ILLUMINANCE("Number:Illuminance"),
    @XmlEnumValue("Number:Intensity")
    NUMBER_INTENSITY("Number:Intensity"),
    @XmlEnumValue("Number:Length")
    NUMBER_LENGTH("Number:Length"),
    @XmlEnumValue("Number:LuminousFlux")
    NUMBER_LUMINOUS_FLUX("Number:LuminousFlux"),
    @XmlEnumValue("Number:LuminousIntensity")
    NUMBER_LUMINOUS_INTENSITY("Number:LuminousIntensity"),
    @XmlEnumValue("Number:MagneticFlux")
    NUMBER_MAGNETIC_FLUX("Number:MagneticFlux"),
    @XmlEnumValue("Number:MagneticFluxDensity")
    NUMBER_MAGNETIC_FLUX_DENSITY("Number:MagneticFluxDensity"),
    @XmlEnumValue("Number:Mass")
    NUMBER_MASS("Number:Mass"),
    @XmlEnumValue("Number:Power")
    NUMBER_POWER("Number:Power"),
    @XmlEnumValue("Number:Pressure")
    NUMBER_PRESSURE("Number:Pressure"),
    @XmlEnumValue("Number:RadiationDoseAbsorbed")
    NUMBER_RADIATION_DOSE_ABSORBED("Number:RadiationDoseAbsorbed"),
    @XmlEnumValue("Number:RadiationDoseEffective")
    NUMBER_RADIATION_DOSE_EFFECTIVE("Number:RadiationDoseEffective"),
    @XmlEnumValue("Number:RadiationSpecificActivity")
    NUMBER_RADIATION_SPECIFIC_ACTIVITY("Number:RadiationSpecificActivity"),
    @XmlEnumValue("Number:RadioactiveActivity")
    NUMBER_RADIOACTIVE_ACTIVITY("Number:RadioactiveActivity"),
    @XmlEnumValue("Number:SolidAngle")
    NUMBER_SOLID_ANGLE("Number:SolidAngle"),
    @XmlEnumValue("Number:Speed")
    NUMBER_SPEED("Number:Speed"),
    @XmlEnumValue("Number:Temperature")
    NUMBER_TEMPERATURE("Number:Temperature"),
    @XmlEnumValue("Number:Time")
    NUMBER_TIME("Number:Time"),
    @XmlEnumValue("Number:Volume")
    NUMBER_VOLUME("Number:Volume"),
    @XmlEnumValue("Number:VolumetricFlowRate")
    NUMBER_VOLUMETRIC_FLOW_RATE("Number:VolumetricFlowRate"),
    @XmlEnumValue("Player")
    PLAYER("Player"),
    @XmlEnumValue("Rollershutter")
    ROLLERSHUTTER("Rollershutter"),
    @XmlEnumValue("String")
    STRING("String"),
    @XmlEnumValue("Switch")
    SWITCH("Switch");
    private final String value;

    XmlItemTypeName(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static XmlItemTypeName fromValue(String v) {
        for (XmlItemTypeName c: XmlItemTypeName.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> openhab-5.1.1.tgz: java/org/openhab/core/thing/internal/dto/XmlItemTypeName.java <==

package org.openhab.core.thing.internal.dto;

import javax.annotation.Generated;
import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for itemTypeName.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <pre>
 * &lt;simpleType name="itemTypeName"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *     &lt;enumeration value="Call"/&gt;
 *     &lt;enumeration value="Color"/&gt;
 *     &lt;enumeration value="Contact"/&gt;
 *     &lt;enumeration value="DateTime"/&gt;
 *     &lt;enumeration value="Dimmer"/&gt;
 *     &lt;enumeration value="Group"/&gt;
 *     &lt;enumeration value="Image"/&gt;
 *     &lt;enumeration value="Location"/&gt;
 *     &lt;enumeration value="Number"/&gt;
 *     &lt;enumeration value="Number:Acceleration"/&gt;
 *     &lt;enumeration value="Number:AmountOfSubstance"/&gt;
 *     &lt;enumeration value="Number:Angle"/&gt;
 *     &lt;enumeration value="Number:Area"/&gt;
 *     &lt;enumeration value="Number:ArealDensity"/&gt;
 *     &lt;enumeration value="Number:CatalyticActivity"/&gt;
 *     &lt;enumeration value="Number:Currency"/&gt;
 *     &lt;enumeration value="Number:DataAmount"/&gt;
 *     &lt;enumeration value="Number:DataTransferRate"/&gt;
 *     &lt;enumeration value="Number:Density"/&gt;
 *     &lt;enumeration value="Number:Dimensionless"/&gt;
 *     &lt;enumeration value="Number:ElectricCapacitance"/&gt;
 *     &lt;enumeration value="Number:ElectricCharge"/&gt;
 *     &lt;enumeration value="Number:ElectricConductance"/&gt;
 *     &lt;enumeration value="Number:ElectricConductivity"/&gt;
 *     &lt;enumeration value="Number:ElectricCurrent"/&gt;
 *     &lt;enumeration value="Number:ElectricInductance"/&gt;
 *     &lt;enumeration value="Number:ElectricPotential"/&gt;
 *     &lt;enumeration value="Number:ElectricResistance"/&gt;
 *     &lt;enumeration value="Number:EmissionIntensity"/&gt;
 *     &lt;enumeration value="Number:Energy"/&gt;
 *     &lt;enumeration value="Number:EnergyPrice"/&gt;
 *     &lt;enumeration value="Number:Force"/&gt;
 *     &lt;enumeration value="Number:Frequency"/&gt;
 *     &lt;enumeration value="Number:Illuminance"/&gt;
 *     &lt;enumeration value="Number:Intensity"/&gt;
 *     &lt;enumeration value="Number:Length"/&gt;
 *     &lt;enumeration value="Number:LuminousFlux"/&gt;
 *     &lt;enumeration value="Number:LuminousIntensity"/&gt;
 *     &lt;enumeration value="Number:MagneticFlux"/&gt;
 *     &lt;enumeration value="Number:MagneticFluxDensity"/&gt;
 *     &lt;enumeration value="Number:Mass"/&gt;
 *     &lt;enumeration value="Number:Power"/&gt;
 *     &lt;enumeration value="Number:Pressure"/&gt;
 *     &lt;enumeration value="Number:RadiationDoseAbsorbed"/&gt;
 *     &lt;enumeration value="Number:RadiationDoseEffective"/&gt;
 *     &lt;enumeration value="Number:RadiationSpecificActivity"/&gt;
 *     &lt;enumeration value="Number:RadioactiveActivity"/&gt;
 *     &lt;enumeration value="Number:SolidAngle"/&gt;
 *     &lt;enumeration value="Number:Speed"/&gt;
 *     &lt;enumeration value="Number:Temperature"/&gt;
 *     &lt;enumeration value="Number:Time"/&gt;
 *     &lt;enumeration value="Number:Volume"/&gt;
 *     &lt;enumeration value="Number:VolumePrice"/&gt;
 *     &lt;enumeration value="Number:VolumetricFlowRate"/&gt;
 *     &lt;enumeration value="Player"/&gt;
 *     &lt;enumeration value="Rollershutter"/&gt;
 *     &lt;enumeration value="String"/&gt;
 *     &lt;enumeration value="Switch"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "itemTypeName")
@XmlEnum
@Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2026-01-08T14:00:59Z")
public enum XmlItemTypeName {

    @XmlEnumValue("Call")
    CALL("Call"),
    @XmlEnumValue("Color")
    COLOR("Color"),
    @XmlEnumValue("Contact")
    CONTACT("Contact"),
    @XmlEnumValue("DateTime")
    DATE_TIME("DateTime"),
    @XmlEnumValue("Dimmer")
    DIMMER("Dimmer"),
    @XmlEnumValue("Group")
    GROUP("Group"),
    @XmlEnumValue("Image")
    IMAGE("Image"),
    @XmlEnumValue("Location")
    LOCATION("Location"),
    @XmlEnumValue("Number")
    NUMBER("Number"),
    @XmlEnumValue("Number:Acceleration")
    NUMBER_ACCELERATION("Number:Acceleration"),
    @XmlEnumValue("Number:AmountOfSubstance")
    NUMBER_AMOUNT_OF_SUBSTANCE("Number:AmountOfSubstance"),
    @XmlEnumValue("Number:Angle")
    NUMBER_ANGLE("Number:Angle"),
    @XmlEnumValue("Number:Area")
    NUMBER_AREA("Number:Area"),
    @XmlEnumValue("Number:ArealDensity")
    NUMBER_AREAL_DENSITY("Number:ArealDensity"),
    @XmlEnumValue("Number:CatalyticActivity")
    NUMBER_CATALYTIC_ACTIVITY("Number:CatalyticActivity"),
    @XmlEnumValue("Number:Currency")
    NUMBER_CURRENCY("Number:Currency"),
    @XmlEnumValue("Number:DataAmount")
    NUMBER_DATA_AMOUNT("Number:DataAmount"),
    @XmlEnumValue("Number:DataTransferRate")
    NUMBER_DATA_TRANSFER_RATE("Number:DataTransferRate"),
    @XmlEnumValue("Number:Density")
    NUMBER_DENSITY("Number:Density"),
    @XmlEnumValue("Number:Dimensionless")
    NUMBER_DIMENSIONLESS("Number:Dimensionless"),
    @XmlEnumValue("Number:ElectricCapacitance")
    NUMBER_ELECTRIC_CAPACITANCE("Number:ElectricCapacitance"),
    @XmlEnumValue("Number:ElectricCharge")
    NUMBER_ELECTRIC_CHARGE("Number:ElectricCharge"),
    @XmlEnumValue("Number:ElectricConductance")
    NUMBER_ELECTRIC_CONDUCTANCE("Number:ElectricConductance"),
    @XmlEnumValue("Number:ElectricConductivity")
    NUMBER_ELECTRIC_CONDUCTIVITY("Number:ElectricConductivity"),
    @XmlEnumValue("Number:ElectricCurrent")
    NUMBER_ELECTRIC_CURRENT("Number:ElectricCurrent"),
    @XmlEnumValue("Number:ElectricInductance")
    NUMBER_ELECTRIC_INDUCTANCE("Number:ElectricInductance"),
    @XmlEnumValue("Number:ElectricPotential")
    NUMBER_ELECTRIC_POTENTIAL("Number:ElectricPotential"),
    @XmlEnumValue("Number:ElectricResistance")
    NUMBER_ELECTRIC_RESISTANCE("Number:ElectricResistance"),
    @XmlEnumValue("Number:EmissionIntensity")
    NUMBER_EMISSION_INTENSITY("Number:EmissionIntensity"),
    @XmlEnumValue("Number:Energy")
    NUMBER_ENERGY("Number:Energy"),
    @XmlEnumValue("Number:EnergyPrice")
    NUMBER_ENERGY_PRICE("Number:EnergyPrice"),
    @XmlEnumValue("Number:Force")
    NUMBER_FORCE("Number:Force"),
    @XmlEnumValue("Number:Frequency")
    NUMBER_FREQUENCY("Number:Frequency"),
    @XmlEnumValue("Number:Illuminance")
    NUMBER_ILLUMINANCE("Number:Illuminance"),
    @XmlEnumValue("Number:Intensity")
    NUMBER_INTENSITY("Number:Intensity"),
    @XmlEnumValue("Number:Length")
    NUMBER_LENGTH("Number:Length"),
    @XmlEnumValue("Number:LuminousFlux")
    NUMBER_LUMINOUS_FLUX("Number:LuminousFlux"),
    @XmlEnumValue("Number:LuminousIntensity")
    NUMBER_LUMINOUS_INTENSITY("Number:LuminousIntensity"),
    @XmlEnumValue("Number:MagneticFlux")
    NUMBER_MAGNETIC_FLUX("Number:MagneticFlux"),
    @XmlEnumValue("Number:MagneticFluxDensity")
    NUMBER_MAGNETIC_FLUX_DENSITY("Number:MagneticFluxDensity"),
    @XmlEnumValue("Number:Mass")
    NUMBER_MASS("Number:Mass"),
    @XmlEnumValue("Number:Power")
    NUMBER_POWER("Number:Power"),
    @XmlEnumValue("Number:Pressure")
    NUMBER_PRESSURE("Number:Pressure"),
    @XmlEnumValue("Number:RadiationDoseAbsorbed")
    NUMBER_RADIATION_DOSE_ABSORBED("Number:RadiationDoseAbsorbed"),
    @XmlEnumValue("Number:RadiationDoseEffective")
    NUMBER_RADIATION_DOSE_EFFECTIVE("Number:RadiationDoseEffective"),
    @XmlEnumValue("Number:RadiationSpecificActivity")
    NUMBER_RADIATION_SPECIFIC_ACTIVITY("Number:RadiationSpecificActivity"),
    @XmlEnumValue("Number:RadioactiveActivity")
    NUMBER_RADIOACTIVE_ACTIVITY("Number:RadioactiveActivity"),
    @XmlEnumValue("Number:SolidAngle")
    NUMBER_SOLID_ANGLE("Number:SolidAngle"),
    @XmlEnumValue("Number:Speed")
    NUMBER_SPEED("Number:Speed"),
    @XmlEnumValue("Number:Temperature")
    NUMBER_TEMPERATURE("Number:Temperature"),
    @XmlEnumValue("Number:Time")
    NUMBER_TIME("Number:Time"),
    @XmlEnumValue("Number:Volume")
    NUMBER_VOLUME("Number:Volume"),
    @XmlEnumValue("Number:VolumePrice")
    NUMBER_VOLUME_PRICE("Number:VolumePrice"),
    @XmlEnumValue("Number:VolumetricFlowRate")
    NUMBER_VOLUMETRIC_FLOW_RATE("Number:VolumetricFlowRate"),
    @XmlEnumValue("Player")
    PLAYER("Player"),
    @XmlEnumValue("Rollershutter")
    ROLLERSHUTTER("Rollershutter"),
    @XmlEnumValue("String")
    STRING("String"),
    @XmlEnumValue("Switch")
    SWITCH("Switch");
    private final String value;

    XmlItemTypeName(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static XmlItemTypeName fromValue(String v) {
        for (XmlItemTypeName c: XmlItemTypeName.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
